% accompanying files:
%
%   MANUAL.PDF: description of installation and usage of LEVEL;
%   CONTENTS.M: description of the files contained in LEVEL;
%   README.TXT: copyright and authors' disclaim;
%
% main external m-files:
%
%   LEVEL.M: main function for approximating the set of curves
%            corresponding to a single-valued level of a given surface;
%   LCONTOUR.M: function using Matlab CONTOUR for comparison with LEVEL for
%               a single-valued level of a given surface;
%
% main internal m-files:
%
%   REF.M: function refining the initial set of segments approximating the
%          level curves by using an adaptive curvature technique and the
%          secant method as described in [1];
%   ADCUR.M: function performing the adaptive curvature technique described
%            in [1];
%   SECANT.M: secant method for refining the level curves segments as
%             described in [1];
%
% m-files for tests:
%
%   TEZT1.M: script running Test 1, i.e. level curves of an academic
%            surface;
%   TEST2.M: script running Test 2, i.e. level curves of the Matlab
%            surface PEAKS;
%   TEST3.M: script running Test 3, i.e. computation of a stability chart
%            for a Delay Differential Equation (DDE);
%   TEST4.M: script running Test 4, i.e. computation of eps-pseudospectra
%            for a first DDE;
%   TEST5.M: script running Test 5, i.e. computation of eps-pseudospectra
%            for a second DDE;
%   FVAL1.M: function evaluating the relevant surface for Test 1;
%   FVAL2.M: function evaluating the relevant surface for Test 2;
%   FVAL3.M: function evaluating the relevant surface for Test 3;
%   FVAL4.M: function evaluating the relevant surface for Test 4;
%   FVAL5.M: function evaluating the relevant surface for Test 5;
%
% additional internal M-files ONLY for tests:
%
%   MODEL.M: internal function in FVAL3 providing the coefficients and
%            delays of the DDE for Test 3;
%   ROOT.M: internal function in FVAL3 approximating the characteristic
%           roots of the DDE provided in MODEL;
%   SPIG.M: internal function in FVAL3 providing the pseudospectral
%           discretization of the infinitesimal generator associated to
%           the DDE provided in MODEL;
%   CHEB.M: internal function in ROOT providing the Chebyshev nodes and
%           differentiation matrix for the pseudospectral discretization
%           performed in SPIG;
%   ELLE.M: internal function in FVAL3 providing the evaluation of the
%           Lagrange coefficients for the pseudospectral discretization
%           performed in SPIG;
%   DESORT.M: internal function in FVAL3 ordering the complex roots
%             produced by SPIG according to their decreasing real part;
%   ORD.M: internal function in FVAL3 ordering the discrete delays and
%          their relevant coefficients for the DDE of Test 3 provided by
%          MODEL;
%   MULTILEVEL.M: main function for approximating the set of curves
%                 corresponding to a multiple-valued level of a given
%                 surface - used in Test 4 and Test 5 for eps-pseudospectra
%                 computation (see [1]);
%   MULTICONTOUR.M: function using Matlab CONTOUR for comparison with
%                   MULTILEVEL for a multiple-valued level - used in Test 4
%                   and Test 5 for eps-pseudospectra computation
%                   (see [1]) and comparison with MULTILEVEL.
%
% Observe that the same algorithms used in ROOT and its associated
% functions SPIG, CHEB, ELLE and DESORT are also utilized in MULTILEVEL
% and MULTICONTOUR for the DDEs of Test 4 and Test 5. For the numerical
% methods underlying those algorithms see
% --- D. Breda, S. Maset and R. Vermiglio, "Pseudospectral differencing
%     methods for characteristic roots of delay differential equations"
%     SIAM J. Sci. Comput., 27(2):482495, 2005.
% --- L. N. Trefethen, "Spectral methods in MATLAB". Software - Environment 
%     - Tools series. SIAM, Philadelphia, USA, 2000. 
%
%
%
%<Reference>
% [1] D. Breda, S. Maset and R. Vermiglio, "An adaptive algorithm for
%     efficient computation of level curves of surfaces"
%     Numerical Algorithms xx (2009), pp.xx-xx.
%
%<Authors>
% D. Breda,
%   Dipartimento di Matematica e Informatica, Universita' di Udine, Italy
% S. Maset
%   Dipartimento di Matematica e Informatica, Universita' di Trieste, Italy
% R. Vermiglio
%   Dipartimento di Matematica e Informatica, Universita' di Udine, Italy
%
% Last revision: december 2008
