function [nev,time]=lcontour(fun,z,r,tol)
%LCONTOUR plot level curves of surfaces
%   [NEV,TIME] = LCONTOUR(FUN,Z,R,TOL) plots the curves of level Z of the
%   function FUN in the rectangular region [R(1),R(2)]x[R(3),R(4)] (defined
%   through the vector R=[R(1),R(2),R(3),R(4)]) within a tolerance TOL. It
%   uses Matlab's CONTOUR. FUN is a function handle. FUN accepts two real
%   scalar inputs X and Y and returns a real scalar function value F,
%   evaluated at X and Y. NEV is the total number of FUN evaluations
%   required to plot the curves and TIME is the overall CPU time.
%
%   The algorithm is used to compare with LEVEL as described in
%   [1] D. Breda, S. Maset and R. Vermiglio, "An adaptive algorithm for
%   efficient computation of level curves of surfaces"
%   Numerical Algorithms xx (2009), pp.xx-xx.
%   Last modified december 24th, 2008.

time=cputime;                    % start computation

Xm=r(1);
XM=r(2);
Ym=r(3);
YM=r(4);

figure(101)                      % set figure
box on
hold on
axis([Xm,XM,Ym,YM])

x=Xm:tol:XM;                     % set x-coords
y=Ym:tol:YM;                     % set y-coords
[X,Y]=meshgrid(x,y);             % create uniform grid
Z=fun(X,Y);                      % evaluate function on grid
contour(X,Y,Z,[z z],'-k');       % call Matlab's contour.m

nev=size(Z,1)*size(Z,2);         % number of f evaluations
time=cputime-time;               % end computation
%-------------------------------------------------------------------------------------%
%-------------------------------------------------------------------------------------%